@@ -1,5 +1,5 @@
 import itertools
-from typing import Any, Dict, Iterable, List, Union
+from typing import Any, Iterable, List, Union
 
 from django.conf import settings
 from django.db.models import Q
@@ -179,14 +179,6 @@ def ip_range_prefixes(start: IPNetwork, end: IPNetwork) -> List[IPNetwork]:
     return iprange_to_cidrs(start.ip, end.ip)
 
 
-def get_device_params(params: Dict[str, Any]) -> Dict[str, Any]:
-    new = params.copy()
-    role = new.pop("role", None)
-    if role is not None:
-        new["device_role"] = role
-    return new
-
-
 def _json_rep(obj: Any) -> Union[str, int, bool, list, dict, None]:
     """Return a JSON serializable representation"""
     if isinstance(obj, (str, int, bool)) or obj is None:
