@@ -37,7 +37,6 @@ from .utils import (
     device_vm_primary_list,
     get_as_cidr_param,
     get_attr_r,
-    get_device_params,
     get_family_param,
     get_service_ips,
     get_summarize_param,
@@ -208,14 +207,6 @@ class DevicesVMsListView(APIView):
     # Therefore, we use Device as the model.
     queryset = Device.objects.all()
 
-    @staticmethod
-    def _get_device_params(params: Dict[str, Any]) -> Dict[str, Any]:
-        new = params.copy()
-        role = new.pop("role", None)
-        if role is not None:
-            new["device_role"] = role
-        return new
-
     @swagger_auto_schema(
         operation_description="Combined devices and virtual machines primary IPs list. "
         "Use only parameters common to both devices and VMs ('role' can be used for both devices and VMs).",
@@ -227,7 +218,7 @@ class DevicesVMsListView(APIView):
         summarize = get_summarize_param(request)
 
         devices_fs = DeviceFilterSet(
-            self._get_device_params(request.query_params),
+            request.query_params,
             queryset=Device.objects.restrict(request.user, "view").all(),
         )
         vms_fs = VirtualMachineFilterSet(
@@ -569,7 +560,7 @@ class DevicesVMsAttrsListView(APIView):
                 device_attrs.append(a)
 
         devices = DeviceFilterSet(
-            get_device_params(request.query_params),
+            request.query_params,
             queryset=Device.objects.restrict(request.user, "view").all(),
         ).qs
         vms = VirtualMachineFilterSet(
